Only the dbc, tabwin, and auxiliary subdirectories managed by microdatasus are removed; the supplied cache root and unrelated files are preserved.
Usage
clear_datasus_cache(cache_dir = datasus_cache_dir())Only the dbc, tabwin, and auxiliary subdirectories managed by microdatasus are removed; the supplied cache root and unrelated files are preserved.
clear_datasus_cache(cache_dir = datasus_cache_dir())