| process_cnes | R Documentation |
Recodes supported CNES fields into descriptive values and normalizes escaped
Unicode text. Establishment ("CNES-ST") and professional ("CNES-PF")
records have different layouts and are processed accordingly.
process_cnes(
data,
information_system = c("CNES-ST", "CNES-PF"),
nomes = FALSE,
municipality_data = TRUE
)
data |
A data frame returned by |
information_system |
A single character string: |
nomes |
Logical scalar. For |
municipality_data |
Logical scalar. If |
Columns not explicitly recoded are retained, but Unicode normalization is applied to every column and consequently the returned tibble contains character columns. Lookup joins can add establishment, occupation, and municipality information.
A tibble with character columns. Supported codes are replaced with descriptions, and requested lookup fields are added where applicable.
Saldanha, R. F. (2026). CNES – Cadastro Nacional de Estabelecimentos de Saúde.
fetch_datasus(), fetch_cadger()
process_cnes(cnes_st_sample, information_system = "CNES-ST")
process_cnes(cnes_pf_sample, information_system = "CNES-PF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.