| process_sih | R Documentation |
Recodes supported fields from reduced hospital-admission records
("SIH-RD") into descriptive values and normalizes escaped Unicode text.
process_sih(data, information_system = "SIH-RD", municipality_data = TRUE)
data |
A data frame returned by |
information_system |
A single character string. Currently only
|
municipality_data |
Logical scalar. If |
Columns not explicitly recoded are retained, but Unicode normalization is
applied to every column and consequently the returned tibble contains
character columns. Other SIH layouts downloadable with fetch_datasus() are
not currently supported by this processing function.
A tibble with character columns. Supported codes are replaced with descriptions, and municipality fields are added when requested and available.
Saldanha, R. F. (2026). SIH – Sistema de Informações Hospitalares do SUS.
fetch_datasus()
process_sih(sih_rd_sample)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.